﻿// ==============================================================================================================
// Microsoft patterns & practices
// CQRS Journey project
// ==============================================================================================================
// ©2012 Microsoft. All rights reserved. Certain content used with permission from contributors
// http://cqrsjourney.github.com/contributors/members
// Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance 
// with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
// Unless required by applicable law or agreed to in writing, software distributed under the License is 
// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
// See the License for the specific language governing permissions and limitations under the License.
// ==============================================================================================================

namespace Infrastructure.Azure.Messaging.Handling
{
    using System.Collections.Generic;
    using System.Diagnostics;
    using System.Linq;
    using Infrastructure.Azure.Messaging;
    using Infrastructure.Messaging.Handling;
    using Infrastructure.Serialization;

    /// <summary>
    /// Processes incoming events from the bus and routes them to the appropriate 
    /// handlers.
    /// </summary>
    // TODO: now that we have just one handler per subscription, it doesn't make 
    // much sense to have this processor doing multi dispatch.
    public class EventProcessor : MessageProcessor, IEventHandlerRegistry
    {
        // A simpler list just works. We don't care about two handlers for the same event 
        // type, etc.
        private List<IEventHandler> handlers = new List<IEventHandler>();

        public EventProcessor(IMessageReceiver receiver, ITextSerializer serializer)
            : base(receiver, serializer)
        {
        }

        public void Register(IEventHandler eventHandler)
        {
            this.handlers.Add(eventHandler);
        }

        protected override void ProcessMessage(string traceIdentifier, object payload)
        {
            var handlerType = typeof(IEventHandler<>).MakeGenericType(payload.GetType());

            foreach (dynamic handler in this.handlers
                .Where(x => handlerType.IsAssignableFrom(x.GetType())))
            {
                Trace.WriteLine("-- Handled by " + ((object)handler).GetType().FullName + traceIdentifier);
                handler.Handle((dynamic)payload);
            }
        }
    }
}
